package org.zheng.demo;

import static org.assertj.core.api.Assertions.assertThat;

public class AssertJApp {

	private static final String CELL_PHONE = "cellPhone";
	private static final String EMAIL = "email";
	private static final String NAME = "name";
	private static final String USER_ID = "id";

	public static void main(String[] args) {
		User actualUser = new User();
		actualUser.setId(USER_ID);
		actualUser.setName(NAME);

		User expectedUser = new User();
		expectedUser.setId(USER_ID);

		printoutUsers(actualUser, expectedUser);
		assertThat(actualUser).usingRecursiveComparison().ignoringFields(NAME, EMAIL).isEqualTo(expectedUser);
		assertThat(actualUser).usingRecursiveComparison().ignoringFields(EMAIL).isNotEqualTo(expectedUser);
		assertThat(actualUser).usingRecursiveComparison().ignoringExpectedNullFields().isEqualTo(expectedUser);

		expectedUser.setName(NAME);
		actualUser.setAge(50);
		assertThat(actualUser).usingRecursiveComparison().ignoringFieldsOfTypes(int.class).isEqualTo(expectedUser);

		actualUser.setCellPhone("1234567");
		expectedUser.setCellPhone("badPhone");
		actualUser.setAge(0);
		printoutUsers(actualUser, expectedUser);
		assertThat(actualUser).usingRecursiveComparison().ignoringFieldsMatchingRegexes(CELL_PHONE)
				.isEqualTo(expectedUser);
		assertThat(actualUser).usingRecursiveComparison().ignoringActualNullFields().isNotEqualTo(expectedUser);

		expectedUser.setCellPhone(null);

		printoutUsers(actualUser, expectedUser);
		assertThat(actualUser).usingRecursiveComparison().ignoringExpectedNullFields().isEqualTo(expectedUser);

		actualUser.setEmail(EMAIL);
		expectedUser.setEmail(EMAIL);

		printoutUsers(actualUser, expectedUser);
		assertThat(actualUser).usingRecursiveComparison().ignoringExpectedNullFields().isEqualTo(expectedUser);

		System.out.println("AssertJApp completed fine.");

	}

	private static void printoutUsers(final User actualUser, final User expectedUser) {
		System.out.println("actualUser=" + actualUser.toString());
		System.out.println("expectedUser=" + expectedUser.toString());
	}

}
